
package net.minecraft.src.pe;

import net.minecraft.src.buildcraft.api.Orientations;
import net.minecraft.src.ic2.api.Direction;

import org.lwjgl.util.vector.Matrix2f;
import org.lwjgl.util.vector.Matrix3f;
import org.lwjgl.util.vector.Vector2f;
import org.lwjgl.util.vector.Vector3f;

public class PEUtil
{
    private static Matrix2f mat2f;
    private static Matrix3f mat3f;

    static
    {
        mat3f = new Matrix3f();
        mat2f = new Matrix2f();
    }

    public static Orientations cableDto(Direction cable)
    {
        switch(cable)
        {
            case ZP: // XPOS
                return Orientations.YPos;
            case ZN:
                return Orientations.YNeg;
            case YN:
                return Orientations.ZNeg;
            case YP:
                return Orientations.ZPos;
            default:
                return dto(cable);
        }
    }

    // Orientation conversion
    public static Orientations dto(Direction d)
    {
        switch(d)
        {
            case XN:
                return Orientations.XNeg;
            case XP:
                return Orientations.XPos;
            case YN:
                return Orientations.YNeg;
            case ZP:
                return Orientations.ZPos;
            case ZN:
                return Orientations.ZNeg;
            default:
                return Orientations.YPos;
        }
    }

    public static Orientations faceToOrient(int side)
    {
        switch(side)
        {
            case 0:
                return Orientations.ZNeg;
            case 1:
                return Orientations.ZPos;
            case 2:
                return Orientations.YNeg;
            case 3:
                return Orientations.YPos;
            case 4:
                return Orientations.XNeg;
            case 5:
                return Orientations.XPos;
            default:
                return Orientations.ZPos;
        }
    }

    public static int orientToFace(Orientations o)
    {
        Direction d = PEUtil.otd(o);
        return d.toSideValue();
    }

    public static Direction otd(Orientations o)
    {
        switch(o)
        {
            case XNeg:
                return Direction.XN;
            case XPos:
                return Direction.XP;
            case YNeg:
                return Direction.YN;
            case ZPos:
                return Direction.ZP;
            case ZNeg:
                return Direction.ZN;
            default:
                return Direction.YP;
        }
    }

    static Vector2f rotate(Vector2f in, float theta)
    {
        mat2f.m00 = (float) Math.cos(theta);
        mat2f.m01 = (float) Math.sin(theta);
        mat2f.m10 = (float) -Math.sin(theta);
        mat2f.m11 = (float) Math.cos(theta);

        Vector2f ret = new Vector2f();
        Matrix2f.transform(mat2f, in, ret);
        return ret;

    }

    static Vector2f translate(Vector2f in, int x, int y)
    {
        Vector3f ret = new Vector3f(in.x, in.y, 1);
        Matrix3f.setIdentity(mat3f);
        mat3f.m20 = x;
        mat3f.m21 = y;
        ret = Matrix3f.transform(mat3f, ret, ret);

        return new Vector2f(ret.x, ret.y);
    }
}
