
package net.minecraft.src.pe;

import java.io.File;
import java.util.logging.Level;

import net.minecraft.client.Minecraft;
import net.minecraft.src.Block;
import net.minecraft.src.Item;
import net.minecraft.src.ItemStack;
import net.minecraft.src.ModLoader;
import net.minecraft.src.mod_PE;
import net.minecraft.src.forge.Configuration;
import net.minecraft.src.forge.Property;

public class PowerExtended
{
    public static Block          blockElectric;
    public static Block          blockMachine;
    public static BlockTurbine   blockTurbine;
    public static int            dmgCopperCable = 1;    // Hard-coded in IC2
    public static int            dmgGlassFibre  = 9;
    public static int            dmgLV          = 3;
    public static int            dmgMV          = 4;
    public static Item           itemCable;
    public static Item           itemIronGear;
    public static int            renderTypeByERI;

    public static int            turbineID;
    private static Configuration config;
    private static boolean       initialized    = false;

    static
    {
        // Try to open the configuration file
        try
        {
            File mc = Minecraft.getMinecraftDir();
            config = new Configuration(new File(mc, "\\config\\PowerExtended\\PE.conf"));
            config.load();
        }
        catch(Exception ex)
        {

        }

        // Initialize blocks
        turbineID = getBlockID(BlockNames.turbineInt, 160);
        blockTurbine = (BlockTurbine) new BlockTurbine(turbineID).setBlockName(BlockNames.turbineInt);

        if(config != null)
        {
            config.save();
        }

        // Now Load Turbine configuration
        Turbine.loadConfig();
    }

    public static int getBlockID(String intName, int def)
    {
        if(config == null)
        {
            return def;
        }
        Property prop = config.getOrCreateBlockIdProperty(intName, def);
        if(prop == null)
        {
            return def;
        }
        String idString = prop.value;
        if(idString == null)
        {
            return def;
        }
        return new Integer(idString);

    }

    public static int getItemID(String intName, int def)
    {
        if(config == null)
        {
            return def;
        }
        Property prop = config.getOrCreateProperty(intName, Configuration.ITEM_PROPERTY, Integer.toString(def));
        if(prop == null)
        {
            return def;
        }
        String idString = prop.value;
        if(idString == null)
        {
            return def;
        }
        return new Integer(idString);

    }

    public static void initialize()
    {
        if(initialized == true)
        {
            return;
        }

        // Do initialization here
        register();
        initializeExternal();
        initializeRecipes();
    }

    public static void initializeExternal()
    {
        try
        {
            // Load classes
            Class bc = Class.forName("BuildCraftCore");
            Class ic2 = Class.forName("mod_IC2");

            // Initialize buildcraft
            bc.getDeclaredMethod("initialize").invoke(null);

            // Blocks
            blockMachine = (Block) ic2.getDeclaredField("blockMachine").get(null);
            blockElectric = (Block) ic2.getDeclaredField("blockElectric").get(null);

            // Items
            itemCable = (Item) ic2.getDeclaredField("itemCable").get(null);
            itemIronGear = (Item) bc.getDeclaredField("ironGearItem").get(null);

        }
        catch(Exception ex)
        {
            ex.printStackTrace();
            ModLoader.getLogger().log(Level.SEVERE, "Could not load base mods: IC2 or Buildcraft");
        }

    }

    public static void initializeModels()
    {
        renderTypeByERI = ModLoader.getUniqueBlockModelID(mod_PE.instance, true);
    }

    public static void initializeRecipes()
    {
        ModLoader.AddRecipe(new ItemStack(blockTurbine, 1, 0), new Object[] { "#@#", "!$!", "#@#", Character.valueOf('#'), itemIronGear,
                Character.valueOf('@'), blockMachine, Character.valueOf('!'), Item.ingotIron, Character.valueOf('$'), new ItemStack(blockElectric, 1, dmgLV) });
        ModLoader.AddRecipe(new ItemStack(blockTurbine, 1, 1), new Object[] { "#@#", "!$!", "#@#", Character.valueOf('#'), itemIronGear,
                Character.valueOf('@'), blockMachine, Character.valueOf('!'), Item.ingotIron, Character.valueOf('$'), new ItemStack(blockElectric, 1, dmgMV) });
    }

    public static void register()
    {
        ModLoader.RegisterTileEntity(TileTurbine.class, "net.minecraft.src.pe.TileTurbine", new RenderTurbine(0));
        ModLoader.RegisterBlock(blockTurbine);
        Item.itemsList[turbineID] = new ItemTurbine(turbineID - 256).setItemName(BlockNames.turbineInt);
        ModLoader.AddLocalization(new StringBuilder().append("tile.").append(BlockNames.turbineInt).append(".zero.name").toString(), "Iron Turbine");
        ModLoader.AddLocalization(new StringBuilder().append("tile.").append(BlockNames.turbineInt).append(".one.name").toString(), "Crystal Turbine");
    }
}
