
package net.minecraft.src.pe;

import net.minecraft.src.ModelBase;
import net.minecraft.src.ModelRenderer;
import net.minecraft.src.TileEntity;
import net.minecraft.src.TileEntitySpecialRenderer;
import net.minecraft.src.mod_PE;
import net.minecraft.src.buildcraft.api.Orientations;
import net.minecraft.src.buildcraft.core.IInventoryRender;
import net.minecraft.src.forge.MinecraftForgeClient;

import org.lwjgl.opengl.GL11;

public class RenderTurbine extends TileEntitySpecialRenderer implements IInventoryRender
{
    private final ModelRenderer bcEnd;
    private final ModelRenderer icEnd;
    private final int           invTier;
    private final ModelBase     model;
    private final ModelRenderer transactor;
    private final ModelRenderer trunk;
    private final ModelRenderer trunkInternal;

    public RenderTurbine(int tier)
    {
        this.invTier = tier;
        this.model = new ModelBase()
        {
        };
        this.bcEnd = new ModelRenderer(this.model, 0, 0);
        this.icEnd = new ModelRenderer(this.model, 0, 0);
        this.trunk = new ModelRenderer(this.model, 0, 0);
        this.trunkInternal = new ModelRenderer(this.model, 0, 0);
        this.transactor = new ModelRenderer(this.model, 0, 0);

        this.bcEnd.addBox(-8.0F, -8.0F, -8.0F, 16, 3, 16);
        this.icEnd.addBox(-8.0F, 5.0F, -8.0F, 16, 3, 16);
        this.trunk.addBox(-4.0F, -5.0F, -4.0F, 8, 10, 8);
        this.trunkInternal.addBox(-3.0F, -5.0F, -3.0F, 6, 10, 6);
        this.transactor.addBox(-8.0F, -5.0F, -8.0F, 16, 3, 16);

        ModelRenderer[] r = { this.bcEnd, this.icEnd, this.trunk, this.transactor, this.trunkInternal };
        for(int i = 0; i < 5; i++)
        {
            r[i].rotationPointX = 8.0F;
            r[i].rotationPointY = 8.0F;
            r[i].rotationPointZ = 8.0F;
        }
    }

    @Override
    public void inventoryRender(double x, double y, double z, float ix, float iy)
    {
        this.renderTurbine(Orientations.ZPos, this.invTier, 0.2f, x, y, z, true);
    }

    @Override
    public void renderTileEntityAt(TileEntity tileentity, double d, double d1, double d2, float f)
    {
        TileTurbine tt = (TileTurbine) tileentity;
        if(tt == null)
        {
            return;
        }

        Orientations o = tt.turbineFacing;
        int tier = tt.tp.tier;
        float slider = tt.tp.sliderPosition;

        // Call The Draw Function
        this.renderTurbine(o, tier, slider, d, d1, d2, false);
    }

    protected void renderTurbine(Orientations o, int tier, float sliderPosition, double d, double d1, double d2, boolean inv)
    {
        float[] angle = { 0.0F, 0.0F, 0.0F };
        float[] translate = { 0.0F, 0.0F, 0.0F };
        switch(o)
        {
            case ZPos:
                translate[1] = 1.0F;// Slider moves positive on y-ax
                break;
            case ZNeg:
                angle[0] = (float) (Math.PI);// 90 degrees left
                translate[1] = -1.0F;// Slider moves negative on y-ax
                break;
            case YNeg:
                angle[0] = (float) -(Math.PI / 2);// Rotate 90 on x-ax, pointing down
                translate[2] = -1.0F;// Slider moves negative on y-ax
                break;
            default: // YPos
                angle[0] = (float) (Math.PI / 2);// Rotate 90 on x-ax, pointing down
                translate[2] = 1.0F;// Slider moves positive on y-ax
                break;
            case XNeg:
                angle[2] = (float) (Math.PI / 2);// Rotate 180 on z-ax
                translate[0] = -1.0F;// Slider moves negative on y-ax
                break;
            case XPos:
                angle[2] = (float) -(Math.PI / 2);// 90 degrees right
                translate[0] = 1.0F;// Slider moves positive on y-ax

                break;
        }

        ModelRenderer[] r = { this.bcEnd, this.icEnd, this.trunk, this.transactor, this.trunkInternal };
        for(int i = 0; i < 5; i++)
        {
            r[i].rotateAngleX = angle[0];
            r[i].rotateAngleY = angle[1];
            r[i].rotateAngleZ = angle[2];
        }

        float factor = 1.0F / 16.0F;

        GL11.glPushMatrix();
        GL11.glDisable(2896);

        GL11.glTranslatef((float) d, (float) d1, (float) d2);

        MinecraftForgeClient.bindTexture(mod_PE.texbaseBc);
        this.bcEnd.render(factor);
        MinecraftForgeClient.bindTexture(mod_PE.texbaseIc);
        this.icEnd.render(factor);

        if(!inv)
        {
            GL11.glEnable(GL11.GL_BLEND);
        }

        // Different textures for coils
        switch(tier)
        {
            case 1:
                MinecraftForgeClient.bindTexture(mod_PE.textrunkred);
                break;
            default:
                MinecraftForgeClient.bindTexture(mod_PE.textrunkbrown);
                break;
        }
        this.trunkInternal.render(factor);

        if(!inv)// Only blend if render is in world
        {
            GL11.glBlendFunc(GL11.GL_SRC_ALPHA, GL11.GL_ONE_MINUS_SRC_ALPHA);
        }

        MinecraftForgeClient.bindTexture(mod_PE.textrunkblue);
        this.trunk.render(factor);

        if(!inv)
        {
            GL11.glDisable(GL11.GL_BLEND);
        }

        // The moving Part
        MinecraftForgeClient.bindTexture(mod_PE.texbaseBc);
        float tlStep = 0.0f;
        tlStep = sliderPosition * ((10.0F - 3.0F) / 16.0F);

        GL11.glTranslatef((translate[0] * tlStep), (translate[1] * tlStep), (translate[2] * tlStep));
        this.transactor.render(factor);

        GL11.glEnable(2896);
        GL11.glPopMatrix();
    }
}
