
package net.minecraft.src.pe;

import net.minecraft.src.EntityPlayer;
import net.minecraft.src.GuiIngame;
import net.minecraft.src.IInventory;
import net.minecraft.src.ItemStack;
import net.minecraft.src.ModLoader;
import net.minecraft.src.NBTTagCompound;
import net.minecraft.src.TileEntity;
import net.minecraft.src.buildcraft.api.IPowerReceptor;
import net.minecraft.src.buildcraft.api.Orientations;
import net.minecraft.src.buildcraft.api.PowerFramework;
import net.minecraft.src.buildcraft.api.PowerProvider;
import net.minecraft.src.ic2.api.Direction;
import net.minecraft.src.ic2.api.EnergyNet;
import net.minecraft.src.ic2.api.IEnergySource;
import net.minecraft.src.ic2.api.IWrenchable;

public class TileTurbine extends PETile implements IPowerReceptor, IEnergySource, IWrenchable, IInventory
{
    static int       debug      = 0;
    boolean          _dbgUpdate = false;

    boolean          isAddedToEnergyNet;
    TurbineProcessor tp;

    Orientations     turbineFacing;

    public TileTurbine()
    {
        super();

        this.tp = new TurbineProcessor(PowerFramework.currentFramework.createPowerProvider(), this);
        this.isAddedToEnergyNet = false;
        this.turbineFacing = Orientations.YPos;
    }

    @Override
    public boolean canInteractWith(EntityPlayer entityplayer)
    {
        return true;
    }

    @Override
    public ItemStack decrStackSize(int i, int j)
    {
        return null;
    }

    @Override
    public void doWork()
    {
    }

    @Override
    public boolean emitsEnergyTo(TileEntity receiver, Direction direction)
    {
        Orientations o = PEUtil.cableDto(direction);
        boolean is = (o == this.turbineFacing);
        if(this._dbgUpdate)
        {
            GuiIngame igG = ModLoader.getMinecraftInstance().ingameGUI;
            igG.addChatMessage("[DOESEMITPOWER]Direction [R=" + o.toString() + ", C=" + this.turbineFacing.toString() + "] does?: " + Boolean.toString(is));
        }
        if(is)
        {
            return true;
        }
        return false;
    }

    @Override
    public void func_35141_y_()
    {
    }

    @Override
    public void func_35142_x_()
    {
    }

    @Override
    public int getInventoryStackLimit()
    {
        return 1;
    }

    @Override
    public String getInvName()
    {
        return "Turbine";
    }

    @Override
    public int getMaxEnergyOutput()
    {
        Turbine t = this.tp.getTurbine();
        return t.getMaxOutputRateEUt();
    }

    @Override
    public PowerProvider getPowerProvider()
    {
        return this.tp.getPowerProvider();
    }

    @Override
    public int getSizeInventory()
    {
        return 1;
    }

    @Override
    public ItemStack getStackInSlot(int i)
    {
        return null;
    }

    public TurbineProcessor getTurbineProcessor()
    {
        return this.tp;
    }

    @Override
    public float getWrenchDropRate()
    {
        Turbine t = this.tp.getTurbine();
        return t.getWrenchDropRate();
    }

    @Override
    public void invalidate()
    {
        if(this.isAddedToEnergyNet)
        {
            if(TileTurbine.debug == 1)
            {
                this.isAddedToEnergyNet = false;
                return;
            }

            EnergyNet enet = EnergyNet.getForWorld(this.worldObj);
            this.tp.setEnergyNet(null);
            enet.removeTileEntity(this);
            this.isAddedToEnergyNet = false;
        }
    }

    @Override
    public boolean isAddedToEnergyNet()
    {
        return this.isAddedToEnergyNet;
    }

    @Override
    public int powerRequest()
    {
        return this.tp.powerRequest();
    }

    @Override
    public void readFromNBT(NBTTagCompound nbttagcompound)
    {
        super.readFromNBT(nbttagcompound);

        // Save information
        int ordinal = new Integer(nbttagcompound.getByte("facing"));
        this.turbineFacing = Orientations.values()[ordinal];

        // Other info
        this.tp.readFromNBT(nbttagcompound);
    }

    @Override
    public void setFacing(short facing)
    {
        Orientations click = PEUtil.faceToOrient(facing);
        this.turbineFacing = click;

        if(this._dbgUpdate)
        {
            GuiIngame igG = ModLoader.getMinecraftInstance().ingameGUI;
            igG.addChatMessage("[WRENCH]Remove turbine faced [" + facing + "]-" + click.toString());
        }

        // Re-Attach to energy net
        this.reAttach();
    }

    @Override
    public void setInventorySlotContents(int i, ItemStack itemstack)
    {
    }

    @Override
    public void setPowerProvider(PowerProvider provider)
    {
        this.tp.provider = provider;
    }

    @Override
    public void updateEntity()
    {
        if(!ModLoader.getMinecraftInstance().running)
        {
            return; // Don't update logic when the game is not running
        }

        if(!this.isAddedToEnergyNet)
        {
            EnergyNet enet = EnergyNet.getForWorld(this.worldObj);
            enet.addTileEntity(this);
            this.tp.setEnergyNet(enet);
            this.isAddedToEnergyNet = true;
        }

        this.tp.updateLogic();
    }

    @Override
    public boolean wrenchRemove(EntityPlayer entityPlayer)
    {
        return true;
    }

    @Override
    public boolean wrenchSetFacing(EntityPlayer entityPlayer, int side)
    {
        Orientations click = PEUtil.faceToOrient(side);

        if(click == this.turbineFacing)
        {
            return false;
        }

        if(this._dbgUpdate)
        {
            GuiIngame igG = ModLoader.getMinecraftInstance().ingameGUI;
            igG.addChatMessage("[WRENCH]Turbine faced Request [" + side + "]-" + click.toString());
        }

        return true;
    }

    @Override
    public void writeToNBT(NBTTagCompound nbttagcompound)
    {
        super.writeToNBT(nbttagcompound);

        nbttagcompound.setByte("facing", (byte) this.turbineFacing.ordinal());

        // Other info
        this.tp.writeToNBT(nbttagcompound);
    }

    protected void reAttach()
    {
        EnergyNet eNet = EnergyNet.getForWorld(this.worldObj);
        if(eNet == null)
        {
            this.isAddedToEnergyNet = false;
            return;
        }
        if(this.isAddedToEnergyNet)
        {
            eNet.removeTileEntity(this);
            this.isAddedToEnergyNet = false;
        }
        eNet.addTileEntity(this);
        this.isAddedToEnergyNet = true;
    }

}
