
package net.minecraft.src.pe;

import java.io.File;
import java.util.Random;

import net.minecraft.client.Minecraft;
import net.minecraft.src.forge.Configuration;
import net.minecraft.src.forge.Property;

public class Turbine
{
    static String        configFile = "\\config\\PowerExtended\\Turbine.conf";

    static float[]       eutBcRate;

    static float[]       maxOutputRateEUt;
    static float[]       maxSpeed;
    static int           maxTier    = 2;
    static float         minThreshold;
    static float[]       powerSpeedMultiplier;
    static float[]       rateVariance;
    static float[]       resetSpeed;
    static float[]       speedDecayRate;
    static Configuration turbineConfig;
    static float[]       wrenchDropRate;
    int                  tier;
    Random               turbineRandom;

    public static void loadConfig()
    {
        minThreshold = 0.0001f;
        eutBcRate = new float[maxTier];
        maxOutputRateEUt = new float[maxTier];
        maxSpeed = new float[maxTier];
        powerSpeedMultiplier = new float[maxTier];
        rateVariance = new float[maxTier];
        resetSpeed = new float[maxTier];
        speedDecayRate = new float[maxTier];
        wrenchDropRate = new float[maxTier];

        try
        {
            File minecraft = Minecraft.getMinecraftDir();
            turbineConfig = new Configuration(new File(minecraft, configFile));
            turbineConfig.load();

            /*
             * for(int i=0; i < maxTier; i++)
             * {
             * maxOutputRateEUt[i];
             * powerSpeedMultiplier[i];
             * rateVariance[i];
             * speedDecayRate[i];
             * wrenchDropRate[i];
             * eutBcRate[i];
             * resetSpeed[i];
             * maxSpeed[i];
             * }
             */

            Property p = turbineConfig.getOrCreateProperty("maxOutputRate0", 0, String.valueOf(32));
            maxOutputRateEUt[0] = new Float(turbineConfig.getOrCreateProperty("maxOutputRate0", 0, String.valueOf(32)).value);
            maxOutputRateEUt[1] = new Float(turbineConfig.getOrCreateProperty("maxOutputRate1", 0, String.valueOf(128)).value);

            powerSpeedMultiplier[0] = (new Float(turbineConfig.getOrCreateProperty("powerSpeedMultiplier0", 0, String.valueOf(0.002f)).value));
            powerSpeedMultiplier[1] = (new Float(turbineConfig.getOrCreateProperty("powerSpeedMultiplier1", 0, String.valueOf(0.001f)).value));

            rateVariance[0] = new Float(turbineConfig.getOrCreateProperty("rateVariance0", 0, String.valueOf(4)).value);
            rateVariance[1] = new Float(turbineConfig.getOrCreateProperty("rateVariance1", 0, String.valueOf(2)).value);

            speedDecayRate[0] = (new Float(turbineConfig.getOrCreateProperty("speedDecayRate0", 0, String.valueOf(0.80f)).value));
            speedDecayRate[1] = (new Float(turbineConfig.getOrCreateProperty("speedDecayRate1", 0, String.valueOf(0.80f)).value));

            wrenchDropRate[0] = (new Float(turbineConfig.getOrCreateProperty("wrenchDropRate0", 0, String.valueOf(0.88f)).value));
            wrenchDropRate[1] = (new Float(turbineConfig.getOrCreateProperty("wrenchDropRate1", 0, String.valueOf(0.95f)).value));

            eutBcRate[0] = (new Float(turbineConfig.getOrCreateProperty("eutBcRate0", 0, String.valueOf(12)).value));
            eutBcRate[1] = (new Float(turbineConfig.getOrCreateProperty("eutBcRate1", 0, String.valueOf(30)).value));

            resetSpeed[0] = (new Float(turbineConfig.getOrCreateProperty("resetSpeed0", 0, String.valueOf(0.02f)).value));
            resetSpeed[1] = (new Float(turbineConfig.getOrCreateProperty("resetSpeed1", 0, String.valueOf(0.02f)).value));

            maxSpeed[0] = (new Float(turbineConfig.getOrCreateProperty("maxSpeed0", 0, String.valueOf(0.25f)).value));
            maxSpeed[1] = (new Float(turbineConfig.getOrCreateProperty("maxSpeed1", 0, String.valueOf(0.25f)).value));

            turbineConfig.save();

        }
        catch(Exception ex)
        {
            ex.printStackTrace();
        }
    }

    public Turbine(int tier)
    {
        this.tier = tier;
        this.turbineRandom = new Random();
    }

    public int getLimitedConversionIC(int bcEnergy, boolean canVary)
    {
        int c = this.getTurbineConversionIC(bcEnergy, canVary);
        if(c > this.getMaxOutputRateEUt())
        {
            c = this.getMaxOutputRateEUt();
        }
        return c;
    }

    public int getMaxOutputRateEUt()
    {
        return (int) Math.floor(maxOutputRateEUt[this.tier]);
    }

    public float getMaxSpeed()
    {
        return maxSpeed[this.tier];
    }

    public float getMinThreshold()
    {
        return minThreshold;
    }

    public float getPowerSpeedMultiplier()
    {
        return powerSpeedMultiplier[this.tier];
    }

    public float getResetSpeed()
    {
        return resetSpeed[this.tier];
    }

    public float getSpeedDecayRate()
    {
        return speedDecayRate[this.tier];
    }

    public int getTier()
    {
        return this.tier;
    }

    public int getTurbineConversionBC(int eu, boolean canVary)
    {
        if(eutBcRate[this.tier] == 0)
        {
            return eu;
        }

        float thisRate = eutBcRate[this.tier];
        if(canVary) // Calculate variance in rate
        {
            thisRate += (this.turbineRandom.nextFloat() % rateVariance[this.tier]) - (rateVariance[this.tier] / 2);
        }
        if(thisRate < 0)
        {
            return 0;
        }
        int c = (int) ((eu) / thisRate);
        return c;
    }

    public int getTurbineConversionIC(int bcEnergy, boolean canVary)
    {
        if(eutBcRate[this.tier] == 0)
        {
            return bcEnergy;
        }

        float thisRate = eutBcRate[this.tier];
        if(canVary)// Calculate variance in rate
        {
            thisRate += (this.turbineRandom.nextFloat() % rateVariance[this.tier]) - (rateVariance[this.tier] / 2);
        }
        if(thisRate < 0)
        {
            return 0;
        }
        int c = (int) (bcEnergy * Turbine.eutBcRate[this.tier]);
        return c;
    }

    public float getWrenchDropRate()
    {
        return wrenchDropRate[this.tier];
    }
}
