
package net.minecraft.src.pe;

import net.minecraft.src.NBTTagCompound;
import net.minecraft.src.TileEntity;
import net.minecraft.src.buildcraft.api.PowerProvider;
import net.minecraft.src.ic2.api.EnergyNet;
import net.minecraft.src.ic2.api.IEnergySource;

public class TurbineProcessor
{
    float         currentSpeed;
    int           dir;
    EnergyNet     enet;
    boolean       isProviderConfigured;
    int           lastPower;
    TileEntity    parentTile;
    PowerProvider provider;
    float         sliderPosition;
    int           tier;
    Turbine       turbine;

    public TurbineProcessor(PowerProvider provider, TileEntity src)
    {
        this.provider = provider;
        this.dir = 1;
        this.lastPower = 0;
        this.sliderPosition = 0.0f;
        this.currentSpeed = 0;
        this.isProviderConfigured = false;
        this.parentTile = src;
    }

    public PowerProvider getPowerProvider()
    {
        if(!this.isProviderConfigured)
        {
            // Configure provider here
            Turbine t = this.getTurbine();
            int max = t.getTurbineConversionBC(t.getMaxOutputRateEUt(), false); // Conversion
                                                                                // Call
            int maxStored = 1024; // Store some energy

            if(TileTurbine.debug != 1)
            {
                this.provider.configure(0, 1, max, 0, maxStored);
            }
            this.isProviderConfigured = true;
        }
        return this.provider;
    }

    public Turbine getTurbine()
    {
        if((this.turbine == null))
        {
            int tier = this.parentTile.getBlockMetadata();
            this.turbine = new Turbine(tier); // Create the turbine class here which defines turbine
                                              // Properties per tier
        }
        return this.turbine;
    }

    public boolean isValid()
    {
        return (this.getPowerProvider() != null) && (this.getTurbine() != null) && (this.enet != null);
    }

    public int powerRequest()
    {
        return this.getTurbine().getTurbineConversionBC(this.getTurbine().getMaxOutputRateEUt(), false);
    }

    public void readFromNBT(NBTTagCompound nbttagcompound)
    {
        this.provider.readFromNBT(nbttagcompound);
        this.isProviderConfigured = true;
    }

    public void setEnergyNet(EnergyNet enet)
    {
        this.enet = enet;
    }

    public void updateEnergyStream()
    {
        if(this.provider.energyStored > 0)
        {
            // Request energy
            // Get energy at position
            Turbine t = this.getTurbine();
            int grabAmount = t.getTurbineConversionBC(t.getMaxOutputRateEUt(), false);

            // Use BC Energy
            int used = this.provider.useEnergy(0, grabAmount, true);

            // Convert BC to IC Energy with variance
            int euPower = t.getLimitedConversionIC(used, true);

            this.lastPower = euPower - this.enet.emitEnergyFrom((IEnergySource) this.parentTile, euPower);
        }
        else
        {
            this.lastPower = 0;
        }
    }

    public void updateLogic()
    {
        this.updateEnergyStream();
        this.updateSliderPosition();
    }

    public void updateSliderPosition()
    {
        Turbine t = this.getTurbine();
        if(t == null)
        {
            return;
        }

        // //
        // Slider Mechanics
        // //

        // Speedup according to conducted power
        this.currentSpeed += this.lastPower * t.getPowerSpeedMultiplier();

        // Speed limits
        if(this.currentSpeed > t.getMaxSpeed())
        {
            this.currentSpeed = t.getMaxSpeed();
        }
        if(this.currentSpeed < Turbine.minThreshold)
        {
            this.currentSpeed = 0;
        }

        // return to base
        if((this.currentSpeed == 0) && (this.sliderPosition > 0.0f))
        {
            this.sliderPosition -= t.getResetSpeed();
            if(this.sliderPosition < 0.0f)
            {
                this.sliderPosition = 0.0f;// Base Reached
                this.dir = 1;
            }
        }

        // Move slider with speed
        this.sliderPosition += (this.dir * this.currentSpeed);
        if(this.sliderPosition > 1.0f)
        {
            this.sliderPosition = 1.0f;
            this.dir = -this.dir;
        }
        if(this.sliderPosition < 0.0f)
        {
            this.sliderPosition = 0.0f;
            this.dir = -this.dir;
        }

        // Decay speed
        this.currentSpeed = t.getSpeedDecayRate() * this.currentSpeed;
        if(this.currentSpeed < 0.0f)
        {
            this.currentSpeed = 0.0f;
        }
    }

    public void writeToNBT(NBTTagCompound nbttagcompound)
    {
        this.provider.writeToNBT(nbttagcompound);
    }
}
